#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cmath>
#include <cctype>

#include <iostream>
#include <sstream>
#include <string>

#include <vector>
#include <list>
#include <queue>
#include <set>
#include <map>
#include <stack>
#include <algorithm>
using namespace std;

#define FOR(i,a,b) for (int i = (a); i < (b); ++i)
#define FOR2(i,a,b) for (int i = (a); i > (b); --i)
/*
#define FOR(i,n) for(int i=0; i < (n); i++)
#define FORD(i,n) for(int i=(n)-1; i >= 0; i--)
#define FORTO(i,a,b) for (int i = (a); i <= (b); ++i)
*/


#define DEBUG(x) cout << '>' << #x << ' ' << x << endl;
#define SIZE(x) int(x.size())

typedef pair<int, int> PII;
typedef long long ll;

#define EPS 1e-6

typedef struct {
	double x, y;
} Point;

Point MakePoint(double x, double y) {
	Point p = { x, y };
	return p;
}

bool Eqal(double a, double b) {
	return abs(a-b) < EPS;
}

double Cross(Point p1, Point p2, Point p3) {
	double x1 = p2.x-p1.x, y1 = p2.y-p1.y;
	double x2 = p3.x-p1.x, y2 = p3.y-p1.y;
	return x1*y2-x2*y1;
}

bool OnSegment(Point p1, Point p2, Point p) {
	double d = Cross(p1,p2,p);
	bool A = (p.x+EPS >= min(p1.x,p2.x) && p.x-EPS <= max(p1.x,p2.x));
	bool B = (p.y+EPS >= min(p1.y,p2.y) && p.y-EPS <= max(p1.y,p2.y));
	return (Eqaldruhy(d,0.0) && A && B);
}

vector<Point> Intersect(Point p1, Point p2, Point p3, Point p4) {
	double A1 = p2.y - p1.y, B1 = p1.x - p2.x;
	double C1 = A1 * p1.x + B1 * p1.y;
	double A2 = p4.y - p3.y, B2 = p3.x - p4.x;
	double C2 = A2 * p3.x + B2 * p3.y;
	double D = A1 * B2 - A2 * B1;
	vector<Point> R;
	if (!D) {
		if (OnSegment(p1,p2,p3)) R.push_back(p3);
		if (OnSegment(p1,p2,p4)) R.push_back(p4);
		if (OnSegment(p3,p4,p1)) R.push_back(p1);
		if (OnSegment(p3,p4,p2)) R.push_back(p2);
	} else {
		R.push_back(MakePoint((B2*C1-B1*C2)/D, (A1*C2-A2*C1)/D));
	}
	return R;
}

double sqr(double x) {
	return x;
}

double Dist(Point A, Point B) {
	return sqrt( sqr(A.x-B.x) + sqr(A.y-B.y) );
}

#define MAXN 123
#define MAXM 4*MAXN*MAXN

typedef pair<Point,Point> PPP;
typedef pair<double,int> PDI;

// lajny
PPP P[MAXN];

// priesecniky na lajne
vector<PDI> I[MAXN];

// prvy koniec
int IA[MAXN];
int IB[MAXN];

// root
int R[MAXM];
list<int> Adj[MAXM];
Point F[MAXM]; // priesecniky

int Find(int v) {
	return R[v] = ((R[v] == v) ? v : Find(R[v]));
}

void Union(int a, int b) {
	R[Find(a)] = Find(b);
}

bool Can(Point a, Point b, Point c) {
	double x1 = b.x-a.x, y1 = b.y-a.y;
	double x2 = c.x-a.x, y2 = c.y-a.y;
	return (x1 * x2 + y1 * y2 >= -EPS);
}

int main()
{
	int N;
	while (true) {
		scanf("%d", &N);
		if (!N) return 0;
		
		FOR(i,N) I[i].clear();
		
		FOR(i,N) {
			Point A, B;
			scanf("%lf %lf %lf %lf", &A.x, &A.y, &B.x, &B.y);
			P[i] = PPP(A,B);
		}
		
		int C = 0;
		
		FOR(i,N) {
			IA[i] = C++;
			I[i].push_back( PDP( 0.0, IA[i] ) );
			IB[i] = C++;
			I[i].push_back( PDP( Dist(P[i].first,P[i].second), IB[i] ) );
		}
		
		FOR(i,N) FOR(j,i) {
			sort(I[i].begin(),I[i].end());
			vector<Point> R = Intersect(P[i].first,P[i].second,P[j].first,P[j].second);
			FOR(k,SIZE(R)) {
				double d1 = Dist(P[i].first,R[k]);
				double d1 = Dist(P[j].first,R[k]);
				I[i].push_back( PDP(d1,C) );
				I[i].push_back( PDP(d2,C) );
				F[C++] = R[k];
			}
		}
		
		FOR(i,C) R[i] = i, Adj[i].clear();
		
		FOR(i,N) {
			sort(I[i].begin(),I[i].end());
			
			FOR(j,SIZE(I[i])) if (j) {
				double d1 = I[j-1].first, i1 = I[j-1].second;
				double d2 = I[j-0].first, i1 = I[j-0].second;
				if (Eqal(d1,d2)) {
					Union(i1,i2);
				} else {
					Adj[i1].push_back(i2);
					Adj[i2].push_back(i1);
				}
			}
		}
		
		FOR(i,C) if (Find(i) != i)
			FOREACH(it,Adj[i]) Adj[Find(i)].push_back(*it);
		
		priority_queue<PDI> Q;
		
		Q.push_back( PDI(0.0,Find(IA[1])) );
		
		while (!Q.empty()) {
			double d = -Q.top().first;
			int v = Q.top().second;
			Q.pop();
			FOREACH(it,Adj[v]) {
				if (Can())
				
				
				
			}
		}
		printf("unreachable\n");
		next:;
	}
	return 0;
}
